# Angular Tree Table

### Dependencies

`Node JS >= 9`

`Angular >= 8`

`npm i jquery` - Dependency for Bootstrap

`npm i bootstrap` - Used this to show the ColumnVisibility dropdown

`npm i file-saver` - Used to store the api exported or generated file

`npm i xlsx` - Used to generate Excel while not using server side processing

`npm i moment` - Used to sort date columns while not using server side processing


### Example:
**app.component.ts**
```
import { Component, OnInit } from '@angular/core';
import { TreeTableHeaderObject, TreeTableRow, TreeTableData, TtDataType } from 'angular-tree-table';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent implements OnInit {
  title = 'test1';
  jCount = 0;

  tableData = null;
  config = {
      level: 0,
      visibleColumnFiltersVisibility: true,
      columnVisibility: false,
      columnVisibilityDropDown: true,
      showExpandArrows: false,
      showExpandAllArrows: false,
      showExpandAllEmptyChildren: false,
      customClassName: 'my-table',
      hidePageLengthDropdown: false,
      columnFilters: {},
      rowClickablesContext: this,
      rowClickables: {},
      commonSearch: true,
      excelExportButton: true,
      extraInfos: [['Total Rows', this.jCount], ['Language', 'Type Script']]
  };
  tableHeaders: TreeTableHeaderObject[] = [];

  ngOnInit() {
    const data = [];
    for (let i = 0; i < 120; i++) {
      this.jCount += 1;
      const row = new TreeTableRow(i + '', {sno: i + 1, name: 'John ' + (i + 1)}, false, null);
      data.push(row);
    }
    this.config.extraInfos = [['Total Rows', this.jCount], ['Language', 'Type Script']];
    this.tableData = new TreeTableData(this.config);
    this.tableInit();
    this.tableData.data = data;
  }

  tableInit() {
    this.tableHeaders.splice(0, this.tableHeaders.length);
    const header = new TreeTableHeaderObject('S.No', 'sno', null, true);
    header.dataType = TtDataType.NUMBER;
    this.tableHeaders.push(header);
    this.tableHeaders.push(new TreeTableHeaderObject('Name', 'name', null, true));
    this.tableHeaders.push(new TreeTableHeaderObject('Name 1', 'name', null, true));
    this.tableHeaders.push(new TreeTableHeaderObject('Name 2', 'name', null, true));
    this.tableHeaders.push(new TreeTableHeaderObject('Name 3', 'name', null, true));
    this.tableHeaders.push(new TreeTableHeaderObject('Name 4', 'name', null, true));
    this.tableData.headers = this.tableHeaders;
  }
}
```

**app.component.html**
```
<div class="container">
  <div class="row">
    <div class="col"></div>
    <div class="col-sm-12">
      <angular-tree-table [tableData]="tableData"></angular-tree-table>
    </div>
    <div class="col"></div>
  </div>
</div>
```


#### Note:  Will add Tree Table Sample, Server side sample & other Properties details soon.